@@ -1,5 +1,6 @@
+import sys
 """This module contains a function that will print the items individually from the list irrespective of its nested depth."""
-def print_list(num_list ,indent = False, level = 0,fh):
+def print_list(num_list ,indent = False, level = 0,fh=sys.stdout):
     """start of the function,A second argument called “level" is used to insert tab-stops when a nested list is encountered."""
     for each in num_list:
         if isinstance(each,list):
